==> vradi-entities-0.2.0-sources.jar: com/jurismarches/vradi/entities/Sending.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.TreeNode;
import org.nuiton.wikitty.TreeNodeAbstract;
import org.nuiton.wikitty.TreeNodeImpl;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Sending extends BusinessEntity {     String EXT_SENDING = "Sending";
     String FIELD_SENDING_SENTDATE = "sentDate";
     String FQ_FIELD_SENDING_SENTDATE = EXT_SENDING + ".sentDate";
     String FIELD_SENDING_RECEPTIONDATE = "receptionDate";
     String FQ_FIELD_SENDING_RECEPTIONDATE = EXT_SENDING + ".receptionDate";
     String FIELD_SENDING_PARAGRAPH = "paragraph";
     String FQ_FIELD_SENDING_PARAGRAPH = EXT_SENDING + ".paragraph";
     String FIELD_SENDING_RECEPTIONPROOF = "receptionProof";
     String FQ_FIELD_SENDING_RECEPTIONPROOF = EXT_SENDING + ".receptionProof";
     String FIELD_SENDING_STATUS = "status";
     String FQ_FIELD_SENDING_STATUS = EXT_SENDING + ".status";
     String FIELD_SENDING_MESSAGEID = "messageId";
     String FQ_FIELD_SENDING_MESSAGEID = EXT_SENDING + ".messageId";
     String FIELD_SENDING_FORM = "form";
     String FQ_FIELD_SENDING_FORM = EXT_SENDING + ".form";
     String FIELD_SENDING_USER = "user";
     String FQ_FIELD_SENDING_USER = EXT_SENDING + ".user";
     String FIELD_SENDING_DELETEDFORMS = "deletedForms";
     String FQ_FIELD_SENDING_DELETEDFORMS = EXT_SENDING + ".deletedForms";
    /**
     * getSentDate :
     * @return Date 
     */

     Date getSentDate();

    /**
     * setSentDate :
     * @param sentDate 
     */

     void setSentDate(Date sentDate);

    /**
     * getReceptionDate :
     * @return Date 
     */

     Date getReceptionDate();

    /**
     * setReceptionDate :
     * @param receptionDate 
     */

     void setReceptionDate(Date receptionDate);

    /**
     * getParagraph :
     * @return String 
     */

     String getParagraph();

    /**
     * setParagraph :
     * @param paragraph 
     */

     void setParagraph(String paragraph);

    /**
     * getReceptionProof :
     * @return boolean 
     */

     boolean getReceptionProof();

    /**
     * setReceptionProof :
     * @param receptionProof 
     */

     void setReceptionProof(boolean receptionProof);

    /**
     * getStatus :
     * @return int 
     */

     int getStatus();

    /**
     * setStatus :
     * @param status 
     */

     void setStatus(int status);

    /**
     * getMessageId :
     * @return String 
     */

     String getMessageId();

    /**
     * setMessageId :
     * @param messageId 
     */

     void setMessageId(String messageId);

    /**
     * getForm :
     * @return Set<String> 
     */

     Set<String> getForm();

    /**
     * addForm :
     * @param element 
     */

     void addForm(String element);

    /**
     * removeForm :
     * @param element 
     */

     void removeForm(String element);

    /**
     * clearForm :
     */

     void clearForm();

    /**
     * getUser :
     * @return String 
     */

     String getUser();

    /**
     * setUser :
     * @param user 
     */

     void setUser(String user);

    /**
     * getDeletedForms :
     * @return Set<String> 
     */

     Set<String> getDeletedForms();

    /**
     * addDeletedForms :
     * @param element 
     */

     void addDeletedForms(String element);

    /**
     * removeDeletedForms :
     * @param element 
     */

     void removeDeletedForms(String element);

    /**
     * clearDeletedForms :
     */

     void clearDeletedForms();


} //Sending

==> vradi-entities-0.3-sources.jar: com/jurismarches/vradi/entities/Sending.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Sending extends BusinessEntity {     String EXT_SENDING = "Sending";
     String FIELD_SENDING_SENTDATE = "sentDate";
     String FQ_FIELD_SENDING_SENTDATE = EXT_SENDING + ".sentDate";
     String FIELD_SENDING_RECEPTIONDATE = "receptionDate";
     String FQ_FIELD_SENDING_RECEPTIONDATE = EXT_SENDING + ".receptionDate";
     String FIELD_SENDING_PARAGRAPH = "paragraph";
     String FQ_FIELD_SENDING_PARAGRAPH = EXT_SENDING + ".paragraph";
     String FIELD_SENDING_RECEPTIONPROOF = "receptionProof";
     String FQ_FIELD_SENDING_RECEPTIONPROOF = EXT_SENDING + ".receptionProof";
     String FIELD_SENDING_STATUS = "status";
     String FQ_FIELD_SENDING_STATUS = EXT_SENDING + ".status";
     String FIELD_SENDING_MESSAGEID = "messageId";
     String FQ_FIELD_SENDING_MESSAGEID = EXT_SENDING + ".messageId";
     String FIELD_SENDING_USER = "user";
     String FQ_FIELD_SENDING_USER = EXT_SENDING + ".user";
     String FIELD_SENDING_DELETEDGROUPFORMS = "deletedGroupForms";
     String FQ_FIELD_SENDING_DELETEDGROUPFORMS = EXT_SENDING + ".deletedGroupForms";
     String FIELD_SENDING_ADDEDGROUPFORMS = "addedGroupForms";
     String FQ_FIELD_SENDING_ADDEDGROUPFORMS = EXT_SENDING + ".addedGroupForms";
     String FIELD_SENDING_GROUPFORMS = "groupForms";
     String FQ_FIELD_SENDING_GROUPFORMS = EXT_SENDING + ".groupForms";
    /**
     * getSentDate :
     * @return Date 
     */

     Date getSentDate();

    /**
     * setSentDate :
     * @param sentDate 
     */

     void setSentDate(Date sentDate);

    /**
     * getReceptionDate :
     * @return Date 
     */

     Date getReceptionDate();

    /**
     * setReceptionDate :
     * @param receptionDate 
     */

     void setReceptionDate(Date receptionDate);

    /**
     * getParagraph :
     * @return String 
     */

     String getParagraph();

    /**
     * setParagraph :
     * @param paragraph 
     */

     void setParagraph(String paragraph);

    /**
     * getReceptionProof :
     * @return boolean 
     */

     boolean getReceptionProof();

    /**
     * setReceptionProof :
     * @param receptionProof 
     */

     void setReceptionProof(boolean receptionProof);

    /**
     * getStatus :
     * @return int 
     */

     int getStatus();

    /**
     * setStatus :
     * @param status 
     */

     void setStatus(int status);

    /**
     * getMessageId :
     * @return String 
     */

     String getMessageId();

    /**
     * setMessageId :
     * @param messageId 
     */

     void setMessageId(String messageId);

    /**
     * getUser :
     * @return String 
     */

     String getUser();

    /**
     * setUser :
     * @param user 
     */

     void setUser(String user);

    /**
     * getDeletedGroupForms :
     * @return Set<String> 
     */

     Set<String> getDeletedGroupForms();

    /**
     * addDeletedGroupForms :
     * @param element 
     */

     void addDeletedGroupForms(String element);

    /**
     * removeDeletedGroupForms :
     * @param element 
     */

     void removeDeletedGroupForms(String element);

    /**
     * clearDeletedGroupForms :
     */

     void clearDeletedGroupForms();

    /**
     * getAddedGroupForms :
     * @return Set<String> 
     */

     Set<String> getAddedGroupForms();

    /**
     * addAddedGroupForms :
     * @param element 
     */

     void addAddedGroupForms(String element);

    /**
     * removeAddedGroupForms :
     * @param element 
     */

     void removeAddedGroupForms(String element);

    /**
     * clearAddedGroupForms :
     */

     void clearAddedGroupForms();

    /**
     * getGroupForms :
     * @return Set<String> 
     */

     Set<String> getGroupForms();

    /**
     * addGroupForms :
     * @param element 
     */

     void addGroupForms(String element);

    /**
     * removeGroupForms :
     * @param element 
     */

     void removeGroupForms(String element);

    /**
     * clearGroupForms :
     */

     void clearGroupForms();


} //Sending
